package com.xy.controller;

import com.xy.annotate.RestMappingController;
import com.xy.dto.DeviceInfoDto;
import com.xy.service.DeviceInfoService;
import com.xy.utils.MercAuthUtils;
import com.xy.utils.PageBean;
import com.xy.utils.R;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;

import javax.validation.Valid;

/**
 * <p>
 *小程序-设备
 * </p>
 *
 * @author hechunping
 * @since 2023/3/4
 */
@RestMappingController("merc-mini/device")
@AllArgsConstructor
@Api(tags = "小程序-设备")
public class MercMiniDeviceController {

    private final DeviceInfoService deviceInfoService;

    @ApiOperation("商户设备首页统计")
    @PostMapping("mercHomeStatistical")
    public R<DeviceInfoDto.MercHomeStatisticalVO> mercHomeStatistical(@RequestBody @Valid DeviceInfoDto.MercHomeQueryDTO dto) {
        dto.setMercId(MercAuthUtils.getMercId());
        return deviceInfoService.mercHomeStatistical(dto);
    }

    @PostMapping("searchPage")
    @ApiOperation("小程序商户设备搜索")
    public R<PageBean<DeviceInfoDto.MerHomeSearchVO>> mercDeviceSearchPage(@RequestBody DeviceInfoDto.Page page) {
        page.setMercId(MercAuthUtils.getMercId());
        return deviceInfoService.mercDeviceSearchPage(page);
    }

    @ApiOperation("小程序商户设备详情-设备信息")
    @PostMapping("detail")
    R<DeviceInfoDto.Vo> detail(@RequestBody DeviceInfoDto.Obj obj) {
        obj.setMercId(MercAuthUtils.getMercId());
        return deviceInfoService.obj(obj);
    }

    @ApiOperation("小程序商户设备详情-数据统计")
    @PostMapping("dataCount")
    R<DeviceInfoDto.DeviceDataCountVO> dataCount(@RequestBody DeviceInfoDto.DeviceDataCountDTO dto) {
        dto.setMercId(MercAuthUtils.getMercId());
        return deviceInfoService.dataCount(dto);
    }
}